require "spec_helper"

RSpec.describe Asciidoctor::BSI do
  before(:all) do
    @blank_hdr = blank_hdr_gen
  end

  it "sorts references" do
    VCR.use_cassette "multistandard" do
      input = <<~INPUT
        = Document title
        Author
        :docfile: test.adoc
        :nodoc:
        :no-isobib-cache:

        <<ref3>>
        <<ref7>>
        <<ref6>>
        <<ref1>>
        <<ref4>>
        <<ref5>>
        <<ref2>>

        [bibliography]
        == Normative References

        [bibliography]
        === Standards publications
        * [[[ref5,ISO 639:1967]]] REF5
        * [[[ref7,IETF RFC 7749]]] REF7

        [bibliography]
        === Other publications
        * [[[ref6,REF6]]] REF6
        * [[[ref4,REF4]]] REF4

        [bibliography]
        == Bibliography

        [bibliography]
        === Standards publications
        * [[[ref2,ISO 15124]]] REF2

        [bibliography]
        === Other publications
        * [[[ref3,REF3]]] REF3
        * [[[ref1,REF1]]] REF1
      INPUT
      output = <<~OUTPUT
                #{@blank_hdr}
                 <preface>
                   <foreword id='_' obligation='informative'>
                     <title>Foreword</title>
                     <p id='_'>
                       <eref type='inline' bibitemid='ref3' citeas='[1]'/>
                       <eref type='inline' bibitemid='ref7' citeas='IETF RFC 7749'/>
                       <eref type='inline' bibitemid='ref6' citeas='[N1]'/>
                       <eref type='inline' bibitemid='ref1' citeas='[2]'/>
                       <eref type='inline' bibitemid='ref4' citeas='[N2]'/>
                       <eref type='inline' bibitemid='ref5' citeas='ISO 639:1967'/>
                       <eref type='inline' bibitemid='ref2' citeas='ISO 15124'/>
                     </p>
                   </foreword>
                 </preface>
                 <sections> </sections>
                 <bibliography>
                   <clause id='_' obligation='informative'>
                     <title>Normative references</title>
                     <p id='_'>
                       The following documents are referred to in the text in such a way that
                       some or all of their content constitutes provisions of this document.
                       For dated references, only the edition cited applies. For undated
                       references, the latest edition of the referenced document (including any
                       amendments) applies.
                     </p>
                     <references normative='true' obligation='informative' id='_' unnumbered='true'>
                       <title>Standards publications</title>
                       <bibitem id='ref7' type='standard'>
                         <fetched>#{Date.today}</fetched>
                         <title format='text/plain' language='en' script='Latn'>The &#8220;xml2rfc&#8221; Version 2 Vocabulary</title>
                         <uri type='xml'>
                           https://raw.githubusercontent.com/relaton/relaton-data-ietf/master/data/reference.RFC.7749.xml
                         </uri>
                         <uri type='src'>https://www.rfc-editor.org/info/rfc7749</uri>
                         <docidentifier type='IETF'>RFC 7749</docidentifier>
                         <docidentifier type='rfc-anchor'>RFC7749</docidentifier>
                         <docidentifier type='DOI'>10.17487/RFC7749</docidentifier>
                         <date type='published'>
                           <on>2016-02</on>
                         </date>
                         <contributor>
                           <role type='author'/>
                           <person>
                             <name>
                               <completename language='en'>J. Reschke</completename>
                             </name>
                             <affiliation>
                               <organization>
                                 <name>Internet Engineering Task Force</name>
                                 <abbreviation>IETF</abbreviation>
                               </organization>
                             </affiliation>
                           </person>
                         </contributor>
                         <contributor>
                           <role type='publisher'/>
                           <organization>
                             <name>Internet Engineering Task Force</name>
                             <abbreviation>IETF</abbreviation>
                           </organization>
                         </contributor>
                         <language>en</language>
                         <script>Latn</script>
                         <abstract format='text/plain' language='en' script='Latn'>
                           This document defines the &#8220;xml2rfc&#8221; version 2
                           vocabulary: an XML-based language used for writing RFCs and
                           Internet-Drafts.Version 2 represents the state of the vocabulary (as
                           implemented by several tools and as used by the RFC Editor) around
                           2014.This document obsoletes RFC 2629.
                         </abstract>
                         <series type='main'>
                           <title format='text/plain' language='en' script='Latn'>RFC</title>
                           <number>7749</number>
                         </series>
                         <place>Fremont, CA</place>
                       </bibitem>
                       <bibitem id='ref5' type='standard'>
                         <title format='text/plain'>REF5</title>
                         <docidentifier type='ISO'>ISO 639:1967</docidentifier>
                         <docnumber>639</docnumber>
                         <date type='published'>
                           <on>1967</on>
                         </date>
                         <contributor>
                           <role type='publisher'/>
                           <organization>
                             <name>International Organization for Standardization</name>
                             <abbreviation>ISO</abbreviation>
                           </organization>
                         </contributor>
                       </bibitem>
                     </references>
                     <references normative='true' obligation='informative' id='_' unnumbered='true'>
                       <title>Other publications</title>
                       <bibitem id='ref6'>
                         <formattedref format='application/x-isodoc+xml'>REF6</formattedref>
                         <docidentifier type='metanorma'>[N1]</docidentifier>
                         <docidentifier>REF6</docidentifier>
                         <docnumber>6</docnumber>
                       </bibitem>
                       <bibitem id='ref4'>
                         <formattedref format='application/x-isodoc+xml'>REF4</formattedref>
                         <docidentifier type='metanorma'>[N2]</docidentifier>
                         <docidentifier>REF4</docidentifier>
                         <docnumber>4</docnumber>
                       </bibitem>
                     </references>
                   </clause>
                   <clause id='_' obligation='informative'>
                     <title>Bibliography</title>
                     <references normative='false' obligation='informative' id='_'>
                       <title>Standards publications</title>
                       <p id='_'>
          For dated references, only the edition cited applies. For undated
          references, the latest edition of the referenced document (including
          any amendments) applies.
        </p>
                       <bibitem id='ref2' type='standard'>
                       <title format='text/plain'>REF2</title>
                        <docidentifier type='ISO'>ISO 15124</docidentifier>
                         <docnumber>15124</docnumber>
                         <contributor>
                           <role type='publisher'/>
                           <organization>
                             <name>International Organization for Standardization</name>
                             <abbreviation>ISO</abbreviation>
                           </organization>
                         </contributor>
                       </bibitem>
                     </references>
                     <references normative='false' obligation='informative' id='_'>
                       <title>Other publications</title>
                       <bibitem id='ref3'>
                         <formattedref format='application/x-isodoc+xml'>REF3</formattedref>
                         <docidentifier type='metanorma'>[1]</docidentifier>
                         <docidentifier>REF3</docidentifier>
                         <docnumber>3</docnumber>
                       </bibitem>
                       <bibitem id='ref1'>
                         <formattedref format='application/x-isodoc+xml'>REF1</formattedref>
                         <docidentifier type='metanorma'>[2]</docidentifier>
                         <docidentifier>REF1</docidentifier>
                         <docnumber>1</docnumber>
                       </bibitem>
                     </references>
                   </clause>
                 </bibliography>
               </bsi-standard>
      OUTPUT
      expect(xmlpp(strip_guid(Asciidoctor
        .convert(input, backend: :bsi, header_footer: true))))
        .to be_equivalent_to xmlpp(output)
    end
  end
end
