require "spec_helper"

RSpec.describe IsoDoc::BSI do
  it "processes notes" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
          <iso-standard xmlns="http://riboseinc.com/isoxml">
          <preface><foreword>
          <note id="_70234f78-64e5-4dfc-8b6f-f3f037348b6a"><name>NOTE</name>
        <p id="_e94663cc-2473-4ccc-9a72-983a74d989f2">Only use paddy or parboiled rice for the determination of husked rice yield.</p>
        <p id="_e94663cc-2473-4ccc-9a72-983a74d989f3">Para 2.</p>
      </note>
          </foreword></preface>
          </iso-standard>
    INPUT
      #{HTML_HDR}
               <div>
                 <h1 class='ForewordTitle'>Foreword</h1>
                 <div class='boilerplate_legal'/>
                 <div id='_70234f78-64e5-4dfc-8b6f-f3f037348b6a' class='Note'>
                   <p>
                   <span class='note_label'>NOTE</span>
                  &#8195;Only use paddy or parboiled rice for the determination of husked
                  rice yield.
                   </p>
                   <p id='_e94663cc-2473-4ccc-9a72-983a74d989f3'>Para 2.</p>
                 </div>
               </div>
               #{IEC_TITLE1}
             </div>
           </body>
         </html>
    OUTPUT
  end

  it "processes commentaries" do
    input = <<~INPUT
              <iso-standard xmlns="http://riboseinc.com/isoxml">
          <sections>
        <clause id='reag2' inline-header='false' obligation='normative'>
          <title>Reagents</title>
          <admonition id='A1' type='commentary' target='reag'>
            <p id='p2'>This is a commentary on the reagents</p>
          </admonition>
          <admonition id='A2' type='commentary' target='reag2'>
            <p id='p2'>This is a commentary on the reagents</p>
          </admonition>
          <admonition id='A3' type='commentary' target='reag2'>
            <p id='p2'>This is a commentary on the reagents</p>
          </admonition>
          <table id='table2'>
            <name>Reagents in use</name>
            <tbody>
              <tr>
                <td valign='top' align='left'>A</td>
                <td valign='top' align='left'>B</td>
              </tr>
            </tbody>
          </table>
        </clause>
        <clause id='reag3' inline-header='false' obligation='normative'>
          <title>Reagents</title>
          <admonition id='A4' type='commentary' target='table3'>
            <p id='p3'>This is a commentary on the reagents</p>
          </admonition>
          <table id='table3'>
            <name>Reagents in use</name>
            <tbody>
              <tr>
                <td valign='top' align='left'>A</td>
                <td valign='top' align='left'>B</td>
              </tr>
            </tbody>
          </table>
        </clause>
      </sections>
      <annex id="sec_C" inline-header="false" obligation="informative"><title>Recognized levels of competence in SM</title><admonition id="_0a120252-23b6-423c-b5b5-e5e5fcb9c8e7" type="commentary" target="sec_C">
<p id="_70c1c77a-dba1-4239-a76f-5610db24835d">This annex provides examples of the levels of competence in SM expected
from individuals working in various roles throughout an organization.
The level of competence required for an individual is determined by the organization.</p>
</admonition>
<p id="_c873a8f4-a2ea-4509-b28c-b85212cca301">Hello</p>
      </annex>
      </iso-standard>
    INPUT

    presxml = <<~OUTPUT
           <iso-standard xmlns="http://riboseinc.com/isoxml" type="presentation">
           <sections>
         <clause id="reag2" inline-header="false" obligation="normative"  displayorder='1'>
           <title depth="1">1<tab/>Reagents</title>
           <admonition id="A1" type="commentary" target="reag"><name>COMMENTARY ON ???</name>
             <p id="p2">This is a commentary on the reagents</p>
           </admonition>
           <admonition id="A2" type="commentary" target="reag2"><name>COMMENTARY 1 ON CLAUSE 1</name>
             <p id="p2">This is a commentary on the reagents</p>
           </admonition>
           <admonition id="A3" type="commentary" target="reag2"><name>COMMENTARY 2 ON CLAUSE 1</name>
             <p id="p2">This is a commentary on the reagents</p>
           </admonition>
           <table id="table2">
             <name>Table 1&#xA0;&#x2014; Reagents in use</name>
             <tbody>
               <tr>
                 <td valign="top" align="left">A</td>
                 <td valign="top" align="left">B</td>
               </tr>
             </tbody>
           </table>
         </clause>
         <clause id="reag3" inline-header="false" obligation="normative" displayorder='2'>
           <title depth="1">2<tab/>Reagents</title>
           <admonition id='A4' type='commentary' target='table3'>
  <name>COMMENTARY ON TABLE 2</name>
  <p id='p3'>This is a commentary on the reagents</p>
</admonition>
           <table id="table3">
             <name>Table 2&#xA0;&#x2014; Reagents in use</name>
             <tbody>
               <tr>
                 <td valign="top" align="left">A</td>
                 <td valign="top" align="left">B</td>
               </tr>
             </tbody>
           </table>
         </clause>
       </sections>
       <annex id='sec_C' inline-header='false' obligation='informative' displayorder='3'>
  <title>
    <strong>Annex A</strong>
    <tab/>
    (informative)
    <br/>
    <strong>Recognized levels of competence in SM</strong>
  </title>
  <admonition id='_0a120252-23b6-423c-b5b5-e5e5fcb9c8e7' type='commentary' target='sec_C'>
  <name>COMMENTARY ON ANNEX A</name>
    <p id='_70c1c77a-dba1-4239-a76f-5610db24835d'>
      This annex provides examples of the levels of competence in SM expected
      from individuals working in various roles throughout an organization.
      The level of competence required for an individual is determined by the
      organization.
    </p>
  </admonition>
  <p id='_c873a8f4-a2ea-4509-b28c-b85212cca301'>Hello</p>
</annex>
       </iso-standard>
    OUTPUT

    html = <<~OUTPUT
      #{HTML_HDR}
             <div id=''>
               <h1 class='ForewordTitle'>Foreword</h1>
               <div class='boilerplate_legal'/>
             </div>
             <p class='zzSTDTitle1'>
               <b/>
             </p>
             <p class='zzSTDTitle1'>&#160;</p>
             <div id='reag2'>
               <h1>1&#8195;Reagents</h1>
               <p>
                 <span class='note_label'>COMMENTARY ON ???</span>
               </p>
               <p id='p2'>This is a commentary on the reagents</p>
               <p>
                 <span class='note_label'>COMMENTARY 1 ON CLAUSE 1</span>
               </p>
               <p id='p2'>This is a commentary on the reagents</p>
               <p>
                 <span class='note_label'>COMMENTARY 2 ON CLAUSE 1</span>
               </p>
               <p id='p2'>This is a commentary on the reagents</p>
               <p class='TableTitle' style='text-align:center;'>Table 1&#160;&#8212; Reagents in use</p>
               <table id='table2' class='MsoISOTable' style='border-width:1px;border-spacing:0;'>
                 <tbody>
                   <tr>
                     <td style='text-align:left;vertical-align:top;border-top:solid windowtext 1.5pt;border-bottom:solid windowtext 1.5pt;'>A</td>
                     <td style='text-align:left;vertical-align:top;border-top:solid windowtext 1.5pt;border-bottom:solid windowtext 1.5pt;'>B</td>
                   </tr>
                 </tbody>
               </table>
             </div>
             <div id='reag3'>
               <h1>2&#8195;Reagents</h1>
               <p>
                 <span class='note_label'>COMMENTARY ON TABLE 2</span>
               </p>
               <p id='p3'>This is a commentary on the reagents</p>
               <p class='TableTitle' style='text-align:center;'>Table 2&#160;&#8212; Reagents in use</p>
               <table id='table3' class='MsoISOTable' style='border-width:1px;border-spacing:0;'>
                 <tbody>
                   <tr>
                     <td style='text-align:left;vertical-align:top;border-top:solid windowtext 1.5pt;border-bottom:solid windowtext 1.5pt;'>A</td>
                     <td style='text-align:left;vertical-align:top;border-top:solid windowtext 1.5pt;border-bottom:solid windowtext 1.5pt;'>B</td>
                   </tr>
                 </tbody>
               </table>
             </div>
             <br/>
<div id='sec_C' class='Section3'>
  <h1 class='Annex'>
    <b>Annex A</b>
    &#8195;
     (informative)
    <br/>
    <b>Recognized levels of competence in SM</b>
  </h1>
  <p>
  <span class='note_label'>COMMENTARY ON ANNEX A</span>
  </p>
  <p id='_70c1c77a-dba1-4239-a76f-5610db24835d'>
     This annex provides examples of the levels of competence in SM
    expected from individuals working in various roles throughout an
    organization. The level of competence required for an individual is
    determined by the organization.
  </p>
  <p id='_c873a8f4-a2ea-4509-b28c-b85212cca301'>Hello</p>
</div>
           </div>
         </body>
       </html>
    OUTPUT
    expect(xmlpp(IsoDoc::BSI::PresentationXMLConvert.new({})
      .convert("test", input, true)))
      .to be_equivalent_to xmlpp(presxml)
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({})
      .convert("test", presxml, true)))
      .to be_equivalent_to xmlpp(html)
  end

  it "processes admonitions" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({})
      .convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
            <iso-standard xmlns="http://riboseinc.com/isoxml">
            <preface><foreword>
            <admonition id="_70234f78-64e5-4dfc-8b6f-f3f037348b6a" type="caution">
          <p id="_e94663cc-2473-4ccc-9a72-983a74d989f2">Only use paddy or parboiled rice for the determination of husked rice yield.</p>
          <p id="_e94663cc-2473-4ccc-9a72-983a74d989f3">Para 2.</p>
        </admonition>
            </foreword></preface>
            </iso-standard>
      INPUT
        #{HTML_HDR}
               <div>
                 <h1 class='ForewordTitle'>Foreword</h1>
                 <div class='boilerplate_legal'/>
                 <div id='_70234f78-64e5-4dfc-8b6f-f3f037348b6a' class='Admonition'>
                   <p>
                     <b>CAUTION</b>. Only use paddy or parboiled rice for the
                     determination of husked rice yield.
                   </p>
                   <p id='_e94663cc-2473-4ccc-9a72-983a74d989f3'>Para 2.</p>
                 </div>
               </div>
        #{IEC_TITLE1}
             </div>
           </body>
         </html>
      OUTPUT
  end

  it "processes admonitions with titles" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
          <iso-standard xmlns="http://riboseinc.com/isoxml">
          <preface><foreword>
          <admonition id="_70234f78-64e5-4dfc-8b6f-f3f037348b6a" type="caution">
          <name>Title</name>
          <ul>
          <li>List</li>
          </ul>
        <p id="_e94663cc-2473-4ccc-9a72-983a74d989f2">Only use paddy or parboiled rice for the determination of husked rice yield.</p>
      </admonition>
          </foreword></preface>
          </iso-standard>
    INPUT
      #{HTML_HDR}
                <div>
                  <h1 class='ForewordTitle'>Foreword</h1>
                  <div class='boilerplate_legal'/>
                  <div id='_70234f78-64e5-4dfc-8b6f-f3f037348b6a' class='Admonition'>
                    <p><b>Title</b>.</p>
                    <ul>
                      <li>List</li>
                    </ul>
                    <p id='_e94663cc-2473-4ccc-9a72-983a74d989f2'>Only use paddy or parboiled rice for the determination of husked rice yield.</p>
                  </div>
                </div>
      #{IEC_TITLE1}
              </div>
            </body>
          </html>
    OUTPUT
  end
end
