require "spec_helper"

RSpec.describe IsoDoc do
  it "processes section names" do
    input = <<~INPUT
      <iso-standard xmlns="http://riboseinc.com/isoxml">
      <preface>
      <foreword obligation="informative">
         <title>Foreword</title>
         <p id="A">This is a preamble</p>
       </foreword>
        <introduction id="B" obligation="informative"><title>Introduction</title><clause id="C" inline-header="false" obligation="informative">
         <title>Introduction Subsection</title>
       </clause>
       <p>This is patent boilerplate</p>
       </introduction></preface><sections>
       <clause id="D" obligation="normative" type="scope">
         <title>Scope</title>
         <p id="E">Text</p>
       </clause>

       <clause id="H" obligation="normative"><title>Terms, definitions, symbols and abbreviated terms</title><terms id="I" obligation="normative">
         <title>Normal Terms</title>
         <term id="J">
         <preferred>Term2</preferred>
       </term>
       </terms>
       <definitions id="K">
         <dl>
         <dt>Symbol</dt>
         <dd>Definition</dd>
         </dl>
       </definitions>
       </clause>
       <definitions id="L">
         <dl>
         <dt>Symbol</dt>
         <dd>Definition</dd>
         </dl>
       </definitions>
       <clause id="M" inline-header="false" obligation="normative"><title>Clause 4</title><clause id="N" inline-header="false" obligation="normative">
         <title>Introduction</title>
       </clause>
       <clause id="O" inline-header="false" obligation="normative">
         <title>Clause 4.2</title>
       </clause></clause>

       </sections><annex id="P" inline-header="false" obligation="normative">
         <title>Annex</title>
         <clause id="Q" inline-header="false" obligation="normative">
         <title>Annex A.1</title>
         <clause id="Q1" inline-header="false" obligation="normative">
         <title>Annex A.1a</title>
         </clause>
       </clause>
              <appendix id="Q2" inline-header="false" obligation="normative">
         <title>An Appendix</title>
       </appendix>
       </annex><bibliography><references id="R" obligation="informative" normative="true">
         <title>Normative References</title>
       </references>
       <clause id="S" obligation="informative">
         <title>Bibliography</title>
         <references id="T" obligation="informative" normative="false">
         <title>Bibliography Subsection</title>
       </references>
       </clause>
       </bibliography>
       </iso-standard>
    INPUT

    presxml = <<~OUTPUT
      <iso-standard xmlns="http://riboseinc.com/isoxml" type="presentation">
      <preface>
      <foreword obligation="informative" displayorder="1">
         <title>Foreword</title>
         <p id="A">This is a preamble</p>
       </foreword>
        <introduction id="B" obligation="informative" displayorder="2"><title depth="1">0<tab/>Introduction</title><clause id="C" inline-header="false" obligation="informative">
         <title depth="2">0.1<tab/>Introduction Subsection</title>
       </clause>
       <p>This is patent boilerplate</p>
       </introduction></preface><sections>
       <clause id="D" obligation="normative" type="scope" displayorder="3">
         <title depth="1">1<tab/>Scope</title>
         <p id="E">Text</p>
       </clause>
       <clause id="H" obligation="normative" displayorder="5"><title depth="1">3<tab/>Terms, definitions, symbols and abbreviated terms</title><terms id="I" obligation="normative">
         <title depth="2">3.1<tab/>Normal Terms</title>
         <term id="J"><name>3.1.1</name>
         <preferred>Term2</preferred>
       </term>
       </terms>
       <definitions id="K" inline-header="true"><title>3.2</title>
         <dl>
         <dt>Symbol</dt>
         <dd>Definition</dd>
         </dl>
       </definitions>
       </clause>
       <definitions id="L" displayorder="6"><title>4</title>
         <dl>
         <dt>Symbol</dt>
         <dd>Definition</dd>
         </dl>
       </definitions>
       <clause id="M" inline-header="false" obligation="normative" displayorder="7"><title depth="1">5<tab/>Clause 4</title><clause id="N" inline-header="false" obligation="normative">
         <title depth="2">5.1<tab/>Introduction</title>
       </clause>
       <clause id="O" inline-header="false" obligation="normative">
         <title depth="2">5.2<tab/>Clause 4.2</title>
       </clause></clause>
       </sections><annex id="P" inline-header="false" obligation="normative" displayorder="8">
         <title><strong>Annex A</strong><tab/>(normative)<br/><strong>Annex</strong></title>
         <clause id="Q" inline-header="false" obligation="normative">
         <title depth="2">A.1<tab/>Annex A.1</title>
         <clause id="Q1" inline-header="false" obligation="normative">
         <title depth="3">A.1.1<tab/>Annex A.1a</title>
         </clause>
       </clause>
              <appendix id="Q2" inline-header="false" obligation="normative">
         <title depth="2">Appendix 1<tab/>An Appendix</title>
       </appendix>
       </annex><bibliography><references id="R" obligation="informative" normative="true" displayorder="4">
         <title depth="1">2<tab/>Normative References</title>
       </references>
       <clause id="S" obligation="informative" displayorder="9">
         <title depth="1">Bibliography</title>
         <references id="T" obligation="informative" normative="false">
         <title depth="2">Bibliography Subsection</title>
       </references>
       </clause>
       </bibliography>
       </iso-standard>
    OUTPUT

    html = <<~OUTPUT
          <html xmlns:epub="http://www.idpf.org/2007/ops" lang="en">
               <head/>
               <body lang="en">
                 <div class="title-section">
                   <p>&#160;</p>
                 </div>
                 <br/>
                 <div class="prefatory-section">
                   <p>&#160;</p>
                 </div>
                 <br/>
                 <div class="main-section">
                   <br/>
                   #{IEC_TITLE}
                      <div>
                        <h1 class="ForewordTitle">Foreword</h1>
                        <div class="boilerplate_legal"/>
                        <p id="A">This is a preamble</p>
                      </div>
                      <br/>
                      <div class="Section3" id="B">
                        <h1 class="IntroTitle">0&#8195;Introduction</h1>
                        <div id="C">
                 <h2>0.1&#8195;Introduction Subsection</h2>
               </div>
                        <p>This is patent boilerplate</p>
                      </div>
                      #{IEC_TITLE1}
                      <div id="D">
                        <h1>1&#8195;Scope</h1>
                        <p id="E">Text</p>
                      </div>
                      <div>
                        <h1>2&#8195;Normative References</h1>
                      </div>
                      <div id="H"><h1>3&#8195;Terms, definitions, symbols and abbreviated terms</h1>
              <div id="I">
                 <h2>3.1&#8195;Normal Terms</h2>
                 <p class="TermNum" id="J">3.1.1</p>
                 <p class="Terms" style="text-align:left;">Term2</p>
               </div><div id="K"><span class='zzMoveToFollowing'>
        <b>3.2&#8195;</b>
      </span>
                 <dl><dt><p>Symbol</p></dt><dd>Definition</dd></dl>
               </div></div>
                      <div id="L" class="Symbols">
                        <h1>4</h1>
                        <dl>
                          <dt>
                            <p>Symbol</p>
                          </dt>
                          <dd>Definition</dd>
                        </dl>
                      </div>
                      <div id="M">
                        <h1>5&#8195;Clause 4</h1>
                        <div id="N">
                 <h2>5.1&#8195;Introduction</h2>
               </div>
                        <div id="O">
                 <h2>5.2&#8195;Clause 4.2</h2>
               </div>
                      </div>
                      <br/>
                      <div id="P" class="Section3">
                        <h1 class="Annex"><b>Annex A</b>&#8195;(normative)<br/><b>Annex</b></h1>
                        <div id="Q">
                 <h2>A.1&#8195;Annex A.1</h2>
                 <div id="Q1">
                 <h3>A.1.1&#8195;Annex A.1a</h3>
                 </div>
               </div>
                        <div id="Q2">
                      <h2>Appendix 1&#8195;An Appendix</h2>
                      </div>
                      </div>
                      <br/>
                      <div>
                        <h1 class="Section3">Bibliography</h1>
                        <div>
                          <h2 class="Section3">Bibliography Subsection</h2>
                        </div>
                      </div>
                    </div>
                  </body>
              </html>
    OUTPUT

    expect(xmlpp(IsoDoc::BSI::PresentationXMLConvert.new({}).convert("test", input, true))).to be_equivalent_to xmlpp(presxml)
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", presxml, true))).to be_equivalent_to xmlpp(html)
  end

  it "processes subclauses with and without titles" do
    expect(xmlpp(IsoDoc::BSI::PresentationXMLConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
            <iso-standard xmlns="http://riboseinc.com/isoxml">
             <sections>
             <clause id="D" obligation="normative">
               <title>Scope</title>
      <clause id="D1" obligation="normative">
               <title>Scope 1</title>
               </clause>
      <clause id="D2" obligation="normative">
               </clause>
             </clause>
             </sections>
             </iso-standard>
    INPUT
      <iso-standard xmlns='http://riboseinc.com/isoxml' type="presentation">
        <sections>
          <clause id='D' obligation='normative' displayorder="1">
            <title depth='1'>
              1
              <tab/>
              Scope
            </title>
            <clause id='D1' obligation='normative'>
              <title depth='2'>
                1.1
                <tab/>
                Scope 1
              </title>
            </clause>
            <clause id='D2' obligation='normative' inline-header='true'>
              <title>1.2</title>
            </clause>
          </clause>
        </sections>
      </iso-standard>
    OUTPUT
  end

  it "processes simple terms & definitions" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
              <iso-standard xmlns="http://riboseinc.com/isoxml">
      <sections>
      <terms id="H" obligation="normative"><title>1<tab/>Terms, Definitions, Symbols and Abbreviated Terms</title>
        <term id="J">
        <name>1.1</name>
        <preferred>Term2</preferred>
      </term>
       </terms>
       </sections>
       </iso-standard>
    INPUT
          #{HTML_HDR}
                      <div id="">
         <h1 class="ForewordTitle">Foreword</h1>
         <div class="boilerplate_legal"/>
       </div>
      #{IEC_TITLE1}
                     <div id="H"><h1>1&#8195;Terms, Definitions, Symbols and Abbreviated Terms</h1>
             <p class="TermNum" id="J">1.1</p>
               <p class="Terms" style="text-align:left;">Term2</p>
             </div>
                   </div>
                 </body>
             </html>
    OUTPUT
  end

  it "processes inline section headers" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
            <iso-standard xmlns="http://riboseinc.com/isoxml">
            <sections>
             <clause id="M" inline-header="false" obligation="normative"><title>1<tab/>Clause 4</title>
      <clause id="N" inline-header="false" obligation="normative">
               <title>1.1<tab/>Introduction</title>
             </clause>
             <clause id="O" inline-header="true" obligation="normative">
               <title>1.2<tab/>Clause 4.2</title>
             </clause></clause>
             </sections>
            </iso-standard>
    INPUT
          #{HTML_HDR}
          <div id="">
        <h1 class="ForewordTitle">Foreword</h1>
        <div class="boilerplate_legal"/>
      </div>
                     #{IEC_TITLE1}
                     <div id="M">
                       <h1>1&#8195;Clause 4</h1>
                       <div id="N">
                <h2>1.1&#8195;Introduction</h2>
              </div>
                       <div id="O">
                <span class="zzMoveToFollowing"><b>1.2&#8195;Clause 4.2&#8195;</b></span>
              </div>
                     </div>
                   </div>
                 </body>
             </html>
    OUTPUT
  end

  it "adds boilerplate to foreword" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
      <iso-standard xmlns="http://riboseinc.com/isoxml">
      <bibdata>
        <ext><doctype>International Standard</doctype></ext>
      </bibdata>
      <boilerplate>
        <legal-statement>
          <p>Boilerplate</p>
        </legal-statement>
      </boilerplate>
      <sections/>
      </iso-standard>
    INPUT
          #{HTML_HDR}
          <div id="">
        <h1 class="ForewordTitle">Foreword</h1>
        <div class="boilerplate_legal">
             <p>Boilerplate</p>
                      </div>
      </div>
                     #{IEC_TITLE1}
                   </div>
                 </body>
             </html>
    OUTPUT
  end

  it "does not add boilerplate to foreword in amendments" do
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({}).convert("test", <<~"INPUT", true))).to be_equivalent_to xmlpp(<<~"OUTPUT")
      <iso-standard xmlns="http://riboseinc.com/isoxml">
      <bibdata>
        <ext><doctype>Amendment</doctype></ext>
      </bibdata>
      <boilerplate>
        <legal-statement>
          <p>Boilerplate</p>
        </legal-statement>
      </boilerplate>
      <sections/>
      </iso-standard>
    INPUT
          #{HTML_HDR}
          <div id="">
        <h1 class="ForewordTitle">Foreword</h1>
      </div>
                     #{IEC_TITLE1}
                   </div>
                 </body>
             </html>
    OUTPUT
  end

  it "deals with unnumbered normative reference subheadings" do
    input = <<~INPUT
      <iso-standard xmlns="http://riboseinc.com/isoxml">
      <sections>
      <clause id="D" obligation="normative" type="scope">
        <title>Scope</title>
        <p id="E">Text</p>
      </clause>
      </sections>
      <bibliography>
      <clause id="S" obligation="normative">
        <title>Bibliography</title>
        <references id="T" obligation="informative" normative="true" unnumbered="true">
        <title>Bibliography Subsection</title>
      </references>
      </clause>
      </bibliography>
      </iso-standard>
    INPUT

    presxml = <<~PRESXML
           <iso-standard xmlns='http://riboseinc.com/isoxml' type='presentation'>
           <sections>
                 <clause id='D' obligation='normative' type='scope' displayorder="1">
                   <title depth='1'>
                     1
                     <tab/>
                     Scope
                   </title>
                   <p id='E'>Text</p>
                 </clause>
               </sections>
               <bibliography>
                 <clause id='S' obligation='normative' displayorder="2">
                   <title depth='1'>
                     2
                     <tab/>
                     Bibliography
                   </title>
                   <references id='T' obligation='informative' normative='true' unnumbered='true'>
        <title depth='2'>Bibliography Subsection</title>
                   </references>
                 </clause>
               </bibliography>
      </iso-standard>
    PRESXML

    html = <<~HTML
           #{HTML_HDR}
            <div id=''>
              <h1 class='ForewordTitle'>Foreword</h1>
              <div class='boilerplate_legal'/>
            </div>
            <p class='zzSTDTitle1'>
              <b/>
            </p>
            <p class='zzSTDTitle1'>&#160;</p>
            <div id='D'>
              <h1> 1 &#8195; Scope </h1>
              <p id='E'>Text</p>
            </div>
            <div>
              <h1> 2 &#8195; Bibliography </h1>
              <div>
                <h2 class='Section3'>Bibliography Subsection</h2>
              </div>
            </div>
          </div>
        </body>
      </html>
    HTML

    expect(xmlpp(IsoDoc::BSI::PresentationXMLConvert.new({})
      .convert("test", input, true))).to be_equivalent_to xmlpp(presxml)
    expect(xmlpp(IsoDoc::BSI::HtmlConvert.new({})
      .convert("test", presxml, true))).to be_equivalent_to xmlpp(html)
  end

  it "renders related BSI references" do
    input = <<~INPUT
             <iso-standard xmlns="http://riboseinc.com/isoxml">
             <bibdata>
             <relation type='related'>
        <bibitem>
          <title>--</title>
          <docidentifier>Committee reference DEF/1</docidentifier>
        </bibitem>
      </relation>
      <relation type='related'>
        <bibitem>
          <title>--</title>
          <docidentifier>Draft for comment 20/30387670 DC</docidentifier>
        </bibitem>
      </relation>
      </bibdata>
      <preface>
      <foreword/>
      </preface>
             <sections/>
             </iso-standard>
    INPUT

    presxml = <<~PRESXML
      <iso-standard xmlns='http://riboseinc.com/isoxml' type='presentation'>
           <bibdata>
             <relation type='related'>
               <bibitem>
                 <title>--</title>
                 <docidentifier>Committee reference DEF/1</docidentifier>
               </bibitem>
             </relation>
             <relation type='related'>
               <bibitem>
                 <title>--</title>
                 <docidentifier>Draft for comment 20/30387670 DC</docidentifier>
               </bibitem>
             </relation>
           </bibdata>
           <preface>
             <clause type='related-refs' displayorder="1">
               <p>
                 The following BSI references relate to the work on this document:
                 <br/>
                 Committee reference DEF/1
                 <br/>
                 Draft for comment 20/30387670 DC
               </p>
             </clause>
             <foreword displayorder="2"/>
           </preface>
           <sections/>
         </iso-standard>
    PRESXML
    expect(xmlpp(IsoDoc::BSI::PresentationXMLConvert.new({})
      .convert("test", input, true)
      .sub(%r{<localized-strings>.*</localized-strings>}m, "")))
      .to be_equivalent_to xmlpp(presxml)
  end
end
